@@ -335,7 +335,7 @@
 (define-key evil-motion-state-map "ze" 'evil-scroll-end-column)
 (define-key evil-motion-state-map "zs" 'evil-scroll-start-column)
 (define-key evil-motion-state-map "zH" 'evil-scroll-left)
-(define-key evil-motion-state-map [?z S-right] 'evil-scroll-left)
+(define-key evil-motion-state-map [?z S-left] 'evil-scroll-left)
 (define-key evil-motion-state-map "zL" 'evil-scroll-right)
 (define-key evil-motion-state-map [?z S-right] 'evil-scroll-right)
 (define-key evil-motion-state-map
